==> dev.biuro-1.18.0.tar.gz: dev.biuro-1.18.0/wp-content/plugins/biuro-contacts/public/partials/biuro-contacts-public--employers.php <==
<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public/partials
 */

/**
 * @link https://codex.wordpress.org/Creating_Options_Pages
 * @link https://www.smashingmagazine.com/2016/04/three-approaches-to-adding-configurable-fields-to-your-plugin/
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) die;
?>

<form name="form-employers" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>" method="post" enctype="multipart/form-data" class="c-form c-form--employers">
    <div id="action" class="c-form--action"></div>

    <?php if (isset($_SESSION['employers--s']) && $_SESSION['employers--s'] == 1) : ?>
        <div class="c-form--success">
            <?php _e('Thank You for contacting!', 'biuro-contacts'); ?>
            <br>
            <?php _e('You request was send successfully, we will contact You.', 'biuro-contacts'); ?>
        </div>
    <?php endif; ?>

    <?php
        if ( isset($_SESSION['employers--captcha-status']) && $_SESSION['employers--captcha-status'] == 'error' ):
    ?>
        <div class="c-form--validation-static c-form--validation-error">
            <?php _e('Sorry, something went wrong. Please try again', 'biuro-contacts'); ?>
        </div>

    <?php
            unset($_SESSION['employers--captcha-status']);
        endif;
     ?>
    <?php

    if ( !$_SESSION['employers--step'] ):
        include_once('biuro-contacts-public--employers--step-1.php');
    else:
        include_once('biuro-contacts-public--employers--step-2.php');
    endif;
 ?>
    <input type="hidden" name="action" value="employers_post">
    <?php wp_nonce_field('employers_post_nonce'); ?>

    <input type="hidden" id="g-recaptcha-response" name="captcha" data-action="employers/">
</form>

<?php if($_SESSION['employers--s'] == 1) {
?>

<script>
window.dataLayer = window.dataLayer || [];
window.dataLayer.push({ event: 'b2b_form_submit_success_validated' });
</script>
<?php
unset($_SESSION['employers--s']);
}?>

<?php if($_SESSION['employers--s'] == 2) {
?>

<div class="c-modal">
    <div class="c-modal--inner">
        <svg width="67px" height="67px">
            <use xlink:href="#ico--success"></use>
        </svg>
        <p><?php _e('Thank You! The information has been successfully supplemented.', 'biuro-contacts'); ?></p>
        <p><button  class="js-modal--close o-btn c-btn--main"><?php _e('OK', 'biuro-contacts'); ?></button></p>
    </div>
</div>

<script>
window.dataLayer = window.dataLayer || [];
window.dataLayer.push({ event: 'b2b_form_update_success_validated' });
</script>

<?php
unset($_SESSION['employers--s']);
}?>

==> dev.biuro-1.20.1.tar.gz: dev.biuro-1.20.1/wp-content/plugins/biuro-contacts/public/partials/biuro-contacts-public--employers.php <==
<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://www.biuro.lt
 * @since      1.0.0
 *
 * @package    Biuro_Contacts
 * @subpackage Biuro_Contacts/public/partials
 */

/**
 * @link https://codex.wordpress.org/Creating_Options_Pages
 * @link https://www.smashingmagazine.com/2016/04/three-approaches-to-adding-configurable-fields-to-your-plugin/
 */
// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) die;
?>

<form name="form-employers" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>" method="post" enctype="multipart/form-data" class="c-form c-form--employers">
    <div id="action" class="c-form--action"></div>

    <?php if (isset($_SESSION['employers--s']) && $_SESSION['employers--s'] == 1) : ?>
        <div class="c-form--success">
            <?php _e('Thank You for contacting!', 'biuro-contacts'); ?>
            <br>
            <?php _e('You request was send successfully, we will contact You.', 'biuro-contacts'); ?>
        </div>
    <?php endif; ?>

    <?php
        if ( isset($_SESSION['employers--captcha-status']) && $_SESSION['employers--captcha-status'] == 'error' ):
    ?>
        <div class="c-form--validation-static c-form--validation-error">
            <?php _e('Sorry, something went wrong. Please try again', 'biuro-contacts'); ?>
        </div>

    <?php
            unset($_SESSION['employers--captcha-status']);
        endif;
     ?>
    <?php

    if ( !$_SESSION['employers--step'] ):
        include_once('biuro-contacts-public--employers--step-1.php');
    else:
        include_once('biuro-contacts-public--employers--step-2.php');
    endif;
 ?>
    <input type="hidden" name="action" value="employers_post">
    <?php wp_nonce_field('employers_post_nonce'); ?>

    <input type="hidden" id="g-recaptcha-response" name="captcha" data-action="employers/">
</form>

<?php if($_SESSION['employers--s'] == 1) {
?>

<script>
window.dataLayer = window.dataLayer || [];
window.dataLayer.push({ event: 'b2b_form_submit_success_validated' });
</script>
<?php
unset($_SESSION['employers--s']);
}?>

<?php if($_SESSION['employers--s'] == 2) {
?>

<div class="c-modal">
    <div class="c-modal--inner">
        <svg width="67px" height="67px">
            <use href="#ico--success"></use>
        </svg>
        <p><?php _e('Thank You! The information has been successfully supplemented.', 'biuro-contacts'); ?></p>
        <p><button  class="js-modal--close o-btn c-btn--main"><?php _e('OK', 'biuro-contacts'); ?></button></p>
    </div>
</div>

<script>
window.dataLayer = window.dataLayer || [];
window.dataLayer.push({ event: 'b2b_form_update_success_validated' });
</script>

<?php
unset($_SESSION['employers--s']);
}?>
